==> jc-1.4.0.tar.gz: soot/dava/RetriggerAnalysisException.h <==
// public class soot.dava.RetriggerAnalysisException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class dfacaace8d2f2f79 soot_dava_RetriggerAnalysisException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_soot_dava_RetriggerAnalysisException_H_
#define _JC_soot_dava_RetriggerAnalysisException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_dava_RetriggerAnalysisException$sub_refs	_jc_soot_dava_RetriggerAnalysisException$sub_refs;
typedef struct _jc_soot_dava_RetriggerAnalysisException$sub_nonrefs	_jc_soot_dava_RetriggerAnalysisException$sub_nonrefs;
typedef struct _jc_soot_dava_RetriggerAnalysisException$refs	_jc_soot_dava_RetriggerAnalysisException$refs;
typedef struct _jc_soot_dava_RetriggerAnalysisException$nonrefs	_jc_soot_dava_RetriggerAnalysisException$nonrefs;
typedef struct _jc_soot_dava_RetriggerAnalysisException$object	_jc_soot_dava_RetriggerAnalysisException$object;

typedef const struct _jc_soot_dava_RetriggerAnalysisException$vmethods	_jc_soot_dava_RetriggerAnalysisException$vmethods;
typedef const struct _jc_soot_dava_RetriggerAnalysisException$vtable	_jc_soot_dava_RetriggerAnalysisException$vtable;
typedef const struct _jc_soot_dava_RetriggerAnalysisException$vtype	_jc_soot_dava_RetriggerAnalysisException$vtype;

// Constructors
extern void _jc_soot_dava_RetriggerAnalysisException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_dava_RetriggerAnalysisException$object *);

// Virtual methods structure
struct _jc_soot_dava_RetriggerAnalysisException$vmethods {
};

// Vtable
struct _jc_soot_dava_RetriggerAnalysisException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_soot_dava_RetriggerAnalysisException$vmethods	soot_dava_RetriggerAnalysisException;
};

// Vtype
struct _jc_soot_dava_RetriggerAnalysisException$vtype {
	_jc_type			type;
	_jc_soot_dava_RetriggerAnalysisException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_RetriggerAnalysisException$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_RetriggerAnalysisException$refs {
    _jc_soot_dava_RetriggerAnalysisException$sub_refs	soot_dava_RetriggerAnalysisException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_RetriggerAnalysisException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_RetriggerAnalysisException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_soot_dava_RetriggerAnalysisException$sub_nonrefs	soot_dava_RetriggerAnalysisException;
};

// Object instance structure
struct _jc_soot_dava_RetriggerAnalysisException$object {
	_jc_soot_dava_RetriggerAnalysisException$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_RetriggerAnalysisException$vtype	*vtype;
	_jc_soot_dava_RetriggerAnalysisException$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_RetriggerAnalysisException$vtype _jc_soot_dava_RetriggerAnalysisException$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_RetriggerAnalysisException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_RetriggerAnalysisException$class_object;

#endif	/* _JC_soot_dava_RetriggerAnalysisException_H_ */

==> jc-1.4.6.tar.gz: soot/dava/RetriggerAnalysisException.h <==
// public class soot.dava.RetriggerAnalysisException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class dfacaace8d2f2f79 soot_dava_RetriggerAnalysisException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_soot_dava_RetriggerAnalysisException_H_
#define _JC_soot_dava_RetriggerAnalysisException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_dava_RetriggerAnalysisException$sub_refs	_jc_soot_dava_RetriggerAnalysisException$sub_refs;
typedef struct _jc_soot_dava_RetriggerAnalysisException$sub_nonrefs	_jc_soot_dava_RetriggerAnalysisException$sub_nonrefs;
typedef struct _jc_soot_dava_RetriggerAnalysisException$refs	_jc_soot_dava_RetriggerAnalysisException$refs;
typedef struct _jc_soot_dava_RetriggerAnalysisException$nonrefs	_jc_soot_dava_RetriggerAnalysisException$nonrefs;
typedef struct _jc_soot_dava_RetriggerAnalysisException$object	_jc_soot_dava_RetriggerAnalysisException$object;

typedef const struct _jc_soot_dava_RetriggerAnalysisException$vmethods	_jc_soot_dava_RetriggerAnalysisException$vmethods;
typedef const struct _jc_soot_dava_RetriggerAnalysisException$vtable	_jc_soot_dava_RetriggerAnalysisException$vtable;
typedef const struct _jc_soot_dava_RetriggerAnalysisException$vtype	_jc_soot_dava_RetriggerAnalysisException$vtype;

// Constructors
extern void _jc_soot_dava_RetriggerAnalysisException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_dava_RetriggerAnalysisException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_RetriggerAnalysisException$vmethods {
};

// Vtable
struct _jc_soot_dava_RetriggerAnalysisException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_soot_dava_RetriggerAnalysisException$vmethods	soot_dava_RetriggerAnalysisException;
};

// Vtype
struct _jc_soot_dava_RetriggerAnalysisException$vtype {
	_jc_type			type;
	_jc_soot_dava_RetriggerAnalysisException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_RetriggerAnalysisException$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_RetriggerAnalysisException$refs {
    _jc_soot_dava_RetriggerAnalysisException$sub_refs	soot_dava_RetriggerAnalysisException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_RetriggerAnalysisException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_RetriggerAnalysisException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_soot_dava_RetriggerAnalysisException$sub_nonrefs	soot_dava_RetriggerAnalysisException;
};

// Object instance structure
struct _jc_soot_dava_RetriggerAnalysisException$object {
	_jc_soot_dava_RetriggerAnalysisException$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_RetriggerAnalysisException$vtype	*vtype;
	_jc_soot_dava_RetriggerAnalysisException$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_RetriggerAnalysisException$vtype _jc_soot_dava_RetriggerAnalysisException$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_RetriggerAnalysisException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_RetriggerAnalysisException$class_object;

#endif	/* _JC_soot_dava_RetriggerAnalysisException_H_ */
